# Targetran

Targetran is a data augmentation library useful for object detection model 
training. It provides a simple API in Python to transform both the images and 
the target rectangular bounding-boxes.
